pub struct Pagination { /* private fields */ }Implementations
Sourceimpl Pagination
impl Pagination
Sourcepub fn new(page: u32, limit: u32, max_limit: Option<u32>) -> Self
pub fn new(page: u32, limit: u32, max_limit: Option<u32>) -> Self
Create new pagination
max_limit is optional and will be clamped between PAGINATION_MIN_LIMIT and PAGINATION_MAX_LIMIT
Examples
use api_tools::value_objects::pagination::{Pagination, PAGINATION_MAX_LIMIT, PAGINATION_MIN_LIMIT};
let pagination = Pagination::new(1, 100, None);
assert_eq!(pagination.page(), 1);
assert_eq!(pagination.limit(), 100);
// Invalid page
let pagination = Pagination::new(0, 100, None);
assert_eq!(pagination.page(), 1);
assert_eq!(pagination.limit(), 100);
// Limit too small
let pagination = Pagination::new(2, 10, None);
assert_eq!(pagination.page(), 2);
assert_eq!(pagination.limit(), PAGINATION_MIN_LIMIT);
// Limit too big
let pagination = Pagination::new(2, 1_000, None);
assert_eq!(pagination.page(), 2);
assert_eq!(pagination.limit(), PAGINATION_MAX_LIMIT);
// Limit too big and max limit greater than max
let pagination = Pagination::new(2, 1_000, Some(800));
assert_eq!(pagination.page(), 2);
assert_eq!(pagination.limit(), PAGINATION_MAX_LIMIT);Sourcepub fn set_max_limit(&mut self, max_limit: u32)
pub fn set_max_limit(&mut self, max_limit: u32)
Set a max limit (between PAGINATION_MIN_LIMIT and PAGINATION_MAX_LIMIT)